import { createCamera } from './camera.js';
import { createCube } from './cube.js';
import { createSphere } from './sphere.js';
import { createCone } from './cone.js';
import { createCylinder } from './cylinder.js';
import { createLights } from './lights.js';
import { createScene } from './scene.js';

import { createControls } from './controls.js';
import { createRenderer } from './renderer.js';
import { Resizer } from './Resizer.js';
import { Loop } from './Loop.js';

let scene;
let camera;
let renderer;
let loop;

class World {
  constructor(container) {
    //original camera position
    camera = createCamera(0, 0, 10);
    //zoom in camera position
    //camera = createCamera(0, 0, 6);
    //zoom out camera position
    //camera = createCamera(0, 0, 15);
    // console.log(camera);
    scene = createScene();
    renderer = createRenderer();

    container.append(renderer.domElement);

    const controls = createControls(camera, renderer.domElement);

    loop = new Loop(camera, scene, renderer);
    container.append(renderer.domElement);

    //createCube(color, size, xOffset, yOffset, zOffset)
    const cube = createCube('purple', 2, 0, 0.5, 0);
    //createSphere(color, radius, xOffset, yOffset, zOffset)
    const sphere = createSphere('red', 0.5, -2, 2, 0);
    //createCone(color, radius, height, xOffset, yOffset, zOffset)
    const cone = createCone('green', 0.5, 1, 2, 2, 0);
    //createCylinder(color, radiusTop, radiusBottom, height, xOffset, yOffset, zOffset);
    const cylinder = createCylinder('aqua', 0.3, 0.5, 0.8, 0, -2, 0);

    //create extra light source to light regions in shadows of purely directional light
    const { ambientLight, mainLight } = createLights();

    // add controls to list of updatables
    loop.updatables.push(cube, sphere, cone, cylinder, controls);

    scene.add(cube, sphere, cone, cylinder, ambientLight, mainLight);

    const resizer = new Resizer(container, camera, renderer);
  }

  render() {
    // draw a single frame
    renderer.render(scene, camera);
  }

  start() {
    loop.start();
  }

  stop() {
    loop.stop();
  }

}

export { World };
