import { BoxGeometry, MathUtils, Mesh, MeshStandardMaterial } from './three.module.js';

function createCube(color, size, xOffset, yOffset, zOffset)
{
  const geometry = new BoxGeometry(size, size, size);

  const material = new MeshStandardMaterial({ color: color });

  const cube = new Mesh(geometry, material);

  cube.rotation.set(-0.5, -0.1, 0.8);

  cube.position.x = xOffset;
  cube.position.y = yOffset;
  cube.position.z = zOffset;

  const radiansPerSecond = MathUtils.degToRad(30);

  // this method will be called once per frame
  cube.tick = (delta) =>
  {
    // increase the cube's rotation each frame
    cube.rotation.z += radiansPerSecond * delta;
    cube.rotation.x += radiansPerSecond * delta;
    cube.rotation.y += radiansPerSecond * delta;
  };

  return cube;
}

export { createCube };
